@@ -3,7 +3,9 @@ models.
 """
 from pysimmods.buffer.batterysim import Battery
 from pysimmods.consumer.hvacsim import HVAC
+from pysimmods.generator.biogassim import BiogasPlant
 from pysimmods.generator.chplpgsystemsim import CHPLPGSystem
+from pysimmods.generator.dieselsim import DieselGenerator
 from pysimmods.generator.pvsystemsim import PVPlantSystem
 
 META = {
@@ -58,6 +60,11 @@ META = {
             "params": ["params", "inits"],
             "attrs": ["set_percent", "p_mw", "q_mvar", "p_th_mw"],
         },
+        "DieselGenerator": {
+            "public": True,
+            "params": ["params", "inits"],
+            "attrs": ["set_percent", "p_mw", "q_mvar"],
+        },
     }
 }
 
@@ -66,4 +73,6 @@ MODELS = {
     "HVAC": HVAC,
     "Battery": Battery,
     "CHP": CHPLPGSystem,
+    "DieselGenerator": DieselGenerator,
+    "Biogas": BiogasPlant,
 }
